egini is a function to compute the Gini index of education for any group of
countries using the set of estimates developed in Jorda and Alonso (2017).egini(countries, init.y, final.y, database, M = 5000, plot = TRUE)South Asia, Europe and Central Asia,
Middle East and North Africa, Latin America and the Caribbean, Advanced
Economies, Sub-Saharan Africa, East Asia and the Pacific and all
for the 142 counrties included in the dataset (see data_country)."total15": Total population aged over-15.
"total25": Total population aged over-25.
"male15": Male population aged over-15.
"male25": Male population aged over-25.
"female15": Female population aged over-15.
"female25": Female population aged over-25.
TRUE (the default), displays a graph of the results.egini returns a list with the following objects:
Gini_index: evolution of the Gini index of education
from the initial to the last year.
countries: countries used to compute the Gini index.
plot = TRUE, graphical representation of the numerical results.
M of the distribution of education of the specified group of countries.
The sample is obtained by Monte Carlo simulation using the mixture of the national
distributions, weighted by their population shares.GenGamma.orig, Gini, data_country.
Visit http://www.educationdata.unican.es for more information on
the constructoin of the dataset and the available
http://www.educationdata.unican.es/countries.egini(countries = c("DNK", "FIN"), init.y = 1995, final.y = 1995,
database = "male25", M = 100, plot = FALSE)
Run the code above in your browser using DataLab