elc is a function to graph the Lorenz curve of education for any group of
countries using the set of estimates developed in Jorda and Alonso (2017).elc(countries, init.y, final.y, database, M = 5000)South Asia, Europe and Central Asia,
Middle East and North Africa, Latin America and the Caribbean, Advanced
Economies, Sub-Saharan Africa, East Asia and the Pacific.
(see data_country)."total15": Total population aged over-15.
"total25": Total population aged over-25.
"male15": Male population aged over-15.
"male25": Male population aged over-25.
"female15": Female population aged over-15.
"female25": Female population aged over-25.
M = 5000).elc returns a graph of the evolution of the Lorenz curve of education
over the specified period.M of the distribution of
education of the specified group of countries.
The sample is obtained by Monte Carlo simulation using the mixture of the national
distributions, weighted by their population shares.GenGamma.orig, Lc,
data_country. Visit http://www.educationdata.unican.es
for more information on the constructoin of the dataset and the available
http://www.educationdata.unican.es/countries.elc(countries = c("CAN","USA"), init.y = 1985, final.y = 1985,
database = "female25", M = 300)
Run the code above in your browser using DataLab