etheil is a function to compute the Theil index of education for any group of
countries included in the dataset developed in Jorda and Alonso (2017).
The function also provides a decomposition of this index in between-county
and within-country inequality.etheil(countries, init.y, final.y, database, plot = TRUE)South Asia, Europe and Central Asia,
Middle East and North Africa, Latin America and the Caribbean, Advanced
Economies, Sub-Saharan Africa, East Asia and the Pacific and all
for the 142 counrties included in the dataset.(see data_country)."total15": Total population aged over-15.
"total25": Total population aged over-25.
"male15": Male population aged over-15.
"male25": Male population aged over-25.
"female15": Female population aged over-15.
"female25": Female population aged over-25.
TRUE (the default), displays a graph of the results.etheil returns a list with the following objects:
Theli_index: evolution of the Theil index of education
from the initial to the last year, decomposed in between-country
and within-country inequality.
countries: countries used to compute the Theil index.
plot = TRUE, graphical representation of the numerical results.
data_country. Visit http://www.educationdata.unican.es
for more information on the constructoin of the dataset and the available
http://www.educationdata.unican.es/countries.etheil(countries = "Advanced Economies", init.y = 1980, final.y = 2000,
database = "male25")
etheil(countries = c("DNK", "FIN", "ISL", "NOR", "SWE"), init.y = 1980,
final.y = 2000, database = "female15")
Run the code above in your browser using DataLab